durationtools.Offset
====================

.. abjad-lineage:: abjad.tools.durationtools.Offset.Offset.Offset

.. autoclass:: abjad.tools.durationtools.Offset.Offset.Offset
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.denominator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.dot_count
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.equal_or_greater_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.equal_or_greater_power_of_two
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.equal_or_lesser_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.equal_or_lesser_power_of_two
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.flag_count
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.has_power_of_two_denominator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.imag
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.is_assignable
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.lilypond_duration_string
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.numerator
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.pair
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.prolation_string
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.real
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.reciprocal
   :noindex:

.. autoattribute:: abjad.tools.durationtools.Offset.Offset.Offset.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.conjugate
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.from_decimal
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.from_float
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.limit_denominator
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.with_denominator
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__abs__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__add__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__complex__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__div__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__divmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__eq__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__float__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__floordiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__ge__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__gt__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__hash__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__le__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__lt__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__mod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__mul__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__ne__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__neg__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__nonzero__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__pos__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__pow__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__radd__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rdiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rdivmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__repr__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rfloordiv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rmod__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rmul__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rpow__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rsub__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__rtruediv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__str__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__sub__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__truediv__
   :noindex:

.. automethod:: abjad.tools.durationtools.Offset.Offset.Offset.__trunc__
   :noindex:
